"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var radium_1 = require("radium");
var React = require("react");
var styles_1 = require("./styles");
exports.ReactComponent = React.PureComponent || React.Component;
exports.orderedBreakpoints = ['col', 'xs', 'ms', 'sm', 'md', 'lg'];
exports.defaultProps = {
    col: 12,
    debug: false,
    direction: 'row',
    gap: 0,
    grow: 0,
    self: 'auto',
    shrink: 1,
    wrap: 'wrap',
};
exports.calculateColumnWidth = function (props, size) {
    var result = exports.orderedBreakpoints.slice(0, exports.orderedBreakpoints.indexOf(size) + 1).reduce(function (acc, breakpoint) { return (typeof props[breakpoint] === 'number' ? props[breakpoint] : acc); }, props.col);
    return typeof result === 'number' ? result : exports.defaultProps.col;
};
var Box = /** @class */ (function (_super) {
    __extends(Box, _super);
    function Box() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Box.prototype.render = function () {
        var children = this.props.children;
        var _a = this.props, className = _a.className, style = _a.style, testId = _a.testId;
        return (React.createElement("div", { className: className, "data-test": testId, style: [this.columns(), this.styles(), style] }, children));
    };
    Box.prototype.getColumnSize = function (size) {
        var _a = this.props, col = _a.col, xs = _a.xs, ms = _a.ms, sm = _a.sm, md = _a.md, lg = _a.lg;
        return exports.calculateColumnWidth({ col: col, xs: xs, ms: ms, sm: sm, md: md, lg: lg }, size);
    };
    Box.prototype.columns = function () {
        var _this = this;
        return exports.orderedBreakpoints
            .map(function (breakpoint) { return _this.getColumnStyle(breakpoint, _this.getColumnSize(breakpoint)); });
    };
    Box.prototype.getColumnStyle = function (breakpoint, columns) {
        var _a;
        return _a = {}, _a["" + styles_1.mediaQueries[breakpoint]] = this.getColumnWidth(columns), _a;
    };
    Box.prototype.getColumnWidth = function (column) {
        var _a = this.props, flex = _a.flex, columns = _a.columns;
        var floor = Math.floor;
        var colCount = columns || styles_1.columns;
        if (column === 0) {
            return { width: 0, display: 'none' };
        }
        var width = column > 0 ? (floor(100000 / colCount * column) / 1000) : 100;
        return { width: width + "%", display: flex ? 'flex' : 'block' };
    };
    Box.prototype.styles = function () {
        var _a = this.props, debug = _a.debug, direction = _a.direction, flex = _a.flex, gap = _a.gap, grow = _a.grow, order = _a.order, self = _a.self, shrink = _a.shrink, wrap = _a.wrap;
        var debugStyles = debug ? styles_1.debugStyle() : {};
        var gapSize = gap === true ? styles_1.defaultGap : gap;
        var gapStyles = typeof gapSize === 'number' && gapSize > 0 ? { paddingLeft: gapSize + "px", paddingRight: gapSize + "px" } : {};
        var flexStyles = flex ? {
            display: 'flex',
            flexDirection: direction,
            flexWrap: wrap,
        } : {};
        return __assign({ display: 'block', alignSelf: self, flexGrow: grow, flexShrink: shrink, order: order, boxSizing: 'border-box', width: '100%' }, flexStyles, gapStyles, debugStyles);
    };
    Box.defaultProps = exports.defaultProps;
    return Box;
}(exports.ReactComponent));
exports.Box = Box;
exports.default = radium_1.default(Box);
//# sourceMappingURL=Box.js.map